@@ -11,6 +11,7 @@ register_report(
         tag          => 'devicebylocation',
         label        => 'By Location',
         provides_csv => 1,
+        api_endpoint => 1,
     }
 );
 
@@ -24,14 +25,12 @@ get '/ajax/content/report/devicebylocation' => require_login sub {
 
     if ( request->is_ajax ) {
         my $json = to_json( \@results );
-        template 'ajax/report/devicebylocation.tt', { results => $json },
-            { layout => undef };
+        template 'ajax/report/devicebylocation.tt', { results => $json };
     }
     else {
         header( 'Content-Type' => 'text/comma-separated-values' );
         template 'ajax/report/devicebylocation_csv.tt',
-            { results => \@results },
-            { layout  => undef };
+            { results => \@results };
     }
 };
 
